@@ -217,7 +217,7 @@ void DebuggerMainWnd::initKAction()
     KStdAction::showStatusbar(this, SLOT(slotViewStatusbar()), actionCollection());
 
     // view menu
-    (void)new KToggleAction(i18n("&Find"), "find", 0, m_filesWindow,
+    (void)new KToggleAction(i18n("&Find"), "find", CTRL+Key_F, m_filesWindow,
 			    SLOT(slotViewFind()), actionCollection(),
 			    "view_find");
     i18n("Source &code");
@@ -401,6 +401,28 @@ void DebuggerMainWnd::restoreSettings(KConfig* config)
     fixDockConfig(config, true);	// upgrade
     readDockConfig(config);
 
+    // Workaround bug #87787: KDockManager stores the titles of the KDockWidgets
+    // in the config files, although they are localized:
+    // If the user changes the language, the titles remain in the previous language.
+    struct { QString text; QWidget* w; } dw[] = {
+	{ i18n("Stack"), m_btWindow },
+	{ i18n("Locals"), m_localVariables },
+	{ i18n("Watches"), m_watches },
+	{ i18n("Registers"), m_registers },
+	{ i18n("Breakpoints"), m_bpTable },
+	{ i18n("Threads"), m_threads },
+	{ i18n("Output"), m_ttyWindow },
+	{ i18n("Memory"), m_memoryWindow }
+    };
+    for (int i = 0; i < sizeof(dw)/sizeof(dw[0]); i++)
+    {
+	KDockWidget* w = dockParent(dw[i].w);
+	w->setTabPageLabel(dw[i].text);
+	// this actually changes the captions in the tabs:
+	QEvent ev(QEvent::CaptionChange);
+	w->event(&ev);
+    }
+
     m_recentExecAction->loadEntries(config, RecentExecutables);
 
     DebuggerMainWndBase::restoreSettings(config);
@@ -827,9 +849,18 @@ void DebuggerMainWnd::slotFileWndEmptyMenu(const QPoint& pos)
 
 void DebuggerMainWnd::slotFileOpen()
 {
-    QString fileName = myGetFileName(i18n("Open"),
-				     m_lastDirectory,
-				     makeSourceFilter(), this);
+    // start browsing in the active file's directory
+    // fall back to last used directory (executable)
+    QString dir = m_lastDirectory;
+    QString fileName = m_filesWindow->activeFileName();
+    if (!fileName.isEmpty()) {
+	QFileInfo fi(fileName);
+	dir = fi.dirPath();
+    }
+
+    fileName = myGetFileName(i18n("Open"),
+			     dir,
+			     makeSourceFilter(), this);
 
     if (!fileName.isEmpty())
     {
