@@ -282,11 +282,9 @@ void ExprWnd::insertExpr(VarTree* expr)
 void ExprWnd::updateExpr(VarTree* expr)
 {
     // search the root variable
-    QString p = expr->getText();
     KPath path;
-    path.push(&p);
+    path.push(expr->getText());
     KTreeViewItem* item = itemAt(path);
-    path.pop();
     if (item == 0) {
 	return;
     }
@@ -474,12 +472,13 @@ void ExprWnd::replaceChildren(VarTree* display, VarTree* newValues)
     ASSERT(display->childCount() == 0 || display->m_varKind != VarTree::VKsimple);
 
     // delete all children of display
-    KTreeViewItem* c;
-    while ((c = display->getChild()) != 0) {
+    while (VarTree* c = static_cast<VarTree*>(display->getChild())) {
+	unhookSubtree(c);
 	display->removeChild(c);
+	delete c;
     }
     // insert copies of the newValues
-    for (c = newValues->getChild(); c != 0; c = c->getSibling()) {
+    for (KTreeViewItem* c = newValues->getChild(); c != 0; c = c->getSibling()) {
 	VarTree* v = static_cast<VarTree*>(c);
 	VarTree* vNew = new VarTree(v->getText(), v->m_nameKind);
 	vNew->m_varKind = v->m_varKind;
@@ -538,21 +537,50 @@ bool ExprWnd::collectUnknownTypes(KTreeViewItem* item, void* user)
 
 VarTree* ExprWnd::topLevelExprByName(const char* name)
 {
-    QString p = name;
     KPath path;
-    path.push(&p);
+    path.push(name);
     KTreeViewItem* item = itemAt(path);
-    path.pop();
 
     return static_cast<VarTree*>(item);
 }
 
+VarTree* ExprWnd::ptrMemberByName(VarTree* v, const QString& name)
+{
+    // v must be a pointer variable, must have children
+    if (v->m_varKind != VarTree::VKpointer || v->childCount() == 0)
+	return 0;
+
+    // the only child of v is the pointer value that represents the struct
+    KTreeViewItem* item = v->getChild();
+    return memberByName(static_cast<VarTree*>(item), name);
+}
+
+VarTree* ExprWnd::memberByName(VarTree* v, const QString& name)
+{
+    // search immediate children for name
+    KTreeViewItem* item = v->getChild();
+    while (item != 0 && item->getText() != name)
+	item = item->getSibling();
+
+    if (item != 0)
+	return static_cast<VarTree*>(item);
+
+    // try in base classes
+    item = v->getChild();
+    while (item != 0 &&
+	   static_cast<VarTree*>(item)->m_nameKind == VarTree::NKtype)
+    {
+	v = memberByName(static_cast<VarTree*>(item), name);
+	if (v != 0)
+	    return v;
+	item = item->getSibling();
+    }
+    return 0;
+}
+
 void ExprWnd::removeExpr(VarTree* item)
 {
-    // must remove any pointers scheduled for update from the list
-    sweepList(m_updatePtrs, item);
-    sweepList(m_updateType, item);
-    sweepList(m_updateStruct, item);
+    unhookSubtree(item);
 
     takeItem(item);
     delete item;
@@ -560,7 +588,16 @@ void ExprWnd::removeExpr(VarTree* item)
     updateValuesWidth();
 }
 
-void ExprWnd::sweepList(QList<VarTree>& list, VarTree* subTree)
+void ExprWnd::unhookSubtree(VarTree* subTree)
+{
+    // must remove any pointers scheduled for update from the list
+    unhookSubtree(m_updatePtrs, subTree);
+    unhookSubtree(m_updateType, subTree);
+    unhookSubtree(m_updateStruct, subTree);
+    emit removingItem(subTree);
+}
+
+void ExprWnd::unhookSubtree(QList<VarTree>& list, VarTree* subTree)
 {
     if (subTree == 0)
 	return;
