@@ -95,6 +95,10 @@ public:
     void updateStructValue(VarTree* display);
     /** get a top-level expression by name */
     VarTree* topLevelExprByName(const char* name);
+    /** return a member of the struct that pointer \a v refers to */
+    static VarTree* ptrMemberByName(VarTree* v, const QString& name);
+    /** return a member of the struct \a v */
+    static VarTree* memberByName(VarTree* v, const QString& name);
     /** removes an expression; must be on the topmost level*/
     void removeExpr(VarTree* item);
     /** retrieves the expression string at the specified line */
@@ -128,12 +132,14 @@ protected:
     ValueEdit m_edit;
 
     /** remove items that are in the subTree from the list */
-    static void sweepList(QList<VarTree>& list, VarTree* subTree);
+    void unhookSubtree(VarTree* subTree);
+    static void unhookSubtree(QList<VarTree>& list, VarTree* subTree);
 
 protected slots:
     void slotExpandOrCollapse(int);
 
 signals:
+    void removingItem(VarTree*);
     void editValueCommitted(int, const QString&);
 };
 
