@@ -1,4 +1,4 @@
-// $Id: main.cpp,v 1.35 2005/01/05 21:06:10 jsixt Exp $
+// $Id$
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -37,9 +37,9 @@ int main(int argc, char** argv)
 			 VERSION,
 			 I18N_NOOP("A Debugger"),
 			 KAboutData::License_GPL, 
-			 "(c) 1998-2005 Johannes Sixt",
+			 "(c) 1998-2006 Johannes Sixt",
 			 0,		/* any text */
-			 "http://members.nextra.at/johsixt/kdbg.html",
+			 "http://www.kdbg.org/",
 			 "Johannes.Sixt@telecom.at");
     aboutData.addAuthor("Johannes Sixt", 0, "Johannes.Sixt@telecom.at");
     aboutData.addCredit("Keith Isdale",
