@@ -68,6 +68,11 @@ void WinStack::reloadAllFiles()
     }
 }
 
+QSize WinStack::sizeHint() const
+{
+    return QSize(640, 480);
+}
+
 void WinStack::activate(const QString& fileName, int lineNo, const DbgAddr& address)
 {
     QFileInfo fi(fileName);
@@ -282,6 +287,14 @@ void WinStack::resizeEvent(QResizeEvent*)
     }
 }
 
+QString WinStack::activeFileName() const
+{
+    QString f;
+    if (m_activeWindow != 0)
+	f = m_activeWindow->fileName();
+    return f;
+}
+
 void WinStack::slotFindForward()
 {
     if (m_activeWindow != 0)
